==> dl.php?src=linea21_2_3_0.zip: linea21/languages/fr/lang_comment.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['comment']['section'] = "Commentaires";

/*
 * Comment
 */
$lang['comment']['nocomment_yet']= "Aucun commentaire n'a été posté.";
$lang['comment']['nocontrib_yet']= "Aucune contribution n'a été postée.";
$lang['comment']['add']= "Ajouter un commentaire";
$lang['comment']['add_contrib']= "Ajouter une contribution";
$lang['comment']['name']= "Identité (Prénom Nom)";
$lang['comment']['email']="Email (non affiché)";
$lang['comment']['website']="Site web";
$lang['comment']['body']="Votre message";
$lang['comment']['email_notification']="Être notifié par email lorsqu'un nouveau commentaire est posté";
$lang['comment']['logged-in_post']="Vous êtes connecté en tant que %s.";
$lang['comment']['go_to']="Voir les commentaires";
$lang['comment']['number']="%s commentaire(s)";
$lang['comment']['comments']="commentaire(s)";
$lang['comment']['successful']="Votre commentaire a été posté avec succès.";
$lang['comment']['successful_contrib']="Merci pour votre contribution. Elle a été postée avec succès !";
$lang['comment']['successful_edit']="Commentaire modifié avec succès.";
$lang['comment']['error_edit']="Le commentaire n'est pas assez long. Les changements ne seront pas pris en compte. Rafraîchissez la page ou tapez \"Ctrl + Z\" pour voir le contenu initial.";
$lang['comment']['moderation_msg']="Les commentaires sont modérés. Votre message apparaîtra après validation par un administrateur.";
$lang['comment']['moderation_msg_contrib']="Les contributions sont modérées. Votre contribution apparaîtra après validation par un administrateur.";
$lang['comment']['only_registered']="Seuls les utilisateurs enregistrés peuvent poster des commentaires. Si vous disposez d'un compte, <a href=\"%s\" class=\"%s\">authentifiez-vous</a>.";
$lang['comment']['only_registered_contrib']="Seuls les utilisateurs enregistrés peuvent poster des contributions. Si vous disposez d'un compte, <a href=\"%s\" class=\"%s\">authentifiez-vous</a>.";
$lang['comment']['create_account']="Vous pouvez aussi <a href=\"%s\" class=\"%s\">créer un compte</a>.";
$lang['comment']['to_moderate']="Message en attente de validation par un administrateur";
$lang['comment']['posted_in']="posté dans";
$lang['comment']['approve']="approuver";
$lang['comment']['disapprove']="désapprouver";
$lang['comment']['approved']="approuvé";
$lang['comment']['disapproved']="désapprouvé";
$lang['comment']['all_approved']="approuvés";
$lang['comment']['all_disapproved']="désapprouvés";
$lang['comment']['delete']="supprimer définitivement";
$lang['comment']['registered_user']="enregistré";

$lang['comment']['published']="Publiés";
$lang['comment']['awaiting']="En attente";

$lang['comment_map']['news']="actualité";
$lang['comment_map']['project']="projet";
$lang['comment_map']['workgroups']="groupe de travail";
$lang['comment_map']['publication']="publication";
$lang['comment_map']['report']="rapport";
$lang['comment_map']['indicator']="indicateur";
$lang['comment_map']['files']="fichier";
$lang['comment_map']['contribute']="contribution";

/*	nommage rubrique module
 *  	*/
$lang['comment']['list']= 'Consultation des commentaires';
$lang['comment']['det']= 'Détails du commentaire';
$lang['comment']['unsubscribe_title']='Désabonnement à la notification automatique des commentaires';
$lang['comment']['unsubscribe_successful']="Vous n'êtes plus abonné aux commentaires.";

/*	check integrité des données
 *  	*/
$lang['comment']['no_name']="Veuillez indiquer votre nom.";
$lang['comment']['no_email']="Veuillez indiquer votre email.";
$lang['comment']['no_body']="Veuillez entrer votre message.";


/*	divers
 *  	*/
$lang['comment']['nb_total']="%d commentaires sont stockés dans la base de données.";
$lang['comment']['status_filter']='Afficher par statut';
$lang['comment']['module_filter']='Afficher par module';
$lang['comment']['module']='Module';
$lang['comment']['all']='Afficher la liste complète';
$lang['comment']['noresult']='Aucun commentaire ne correspond à ce(s) critère(s) de sélection ';


/*	public
 *  	*/
$lang['comment']['mail_subject_newcomment']='Un nouveau commentaire a été posté - %s';
$lang['comment']['mail_subject_moderate']='Modérer un nouveau commentaire - %s';
$lang['comment']['mail_body1']='%s a posté un nouveau commentaire dans %s';
$lang['comment']['mail_body2']='modérer';
$lang['comment']['mail_body3']='Vous recevez ce message car vous vous êtes abonné. Pour ne plus recevoir de notification, suivez ce lien : ';
$lang['comment']['mail_body_auth'] = 'Important : Vous devez être authentifié pour y avoir accès.';

/*	public
 *  	*/

$lang['comment']['name2']='commentaire(s)';

$lang['comment']['contribute_item']='Contributions';
$lang['comment']['contribute_title']='Donnez votre opinion!';
$lang['comment']['contribute_chapo']='La plateforme mise en place vous offre la possibilité de vous exprimer sur notre démarche.';

$lang['comment']['contrib_none']='A ce jour, aucune contribution n\'a été reçue.';
$lang['comment']['contrib_singular']='A ce jour, une contribution a été reçue.';
$lang['comment']['contrib_plural']='A ce jour, %s contributions ont été reçues.';

$lang['comment']['help_1']='Vous pouvez supprimer définitivement un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';
$lang['comment']['help_2']='Vous pouvez approuver un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';
$lang['comment']['help_3']='Vous pouvez désapprouver un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';

?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/fr/lang_comment.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['comment']['section'] = "Commentaires";

/*
 * Comment
 */
$lang['comment']['nocomment_yet']= "Aucun commentaire n'a été posté.";
$lang['comment']['nocontrib_yet']= "Aucune contribution n'a été postée.";
$lang['comment']['add']= "Ajouter un commentaire";
$lang['comment']['add_contrib']= "Ajouter une contribution";
$lang['comment']['name']= "Identité (Prénom Nom)";
$lang['comment']['name_short']= "Nom";
$lang['comment']['email']="Email (non affiché)";
$lang['comment']['website']="Site web";
$lang['comment']['body']="Votre message";
$lang['comment']['email_notification']="Être notifié par email lorsqu'un nouveau commentaire est posté";
$lang['comment']['logged-in_post']="Vous êtes connecté en tant que %s.";
$lang['comment']['go_to']="Voir les commentaires";
$lang['comment']['number']="%s commentaire(s)";
$lang['comment']['comments']="commentaire(s)";
$lang['comment']['successful']="Votre commentaire a été posté avec succès.";
$lang['comment']['successful_contrib']="Merci pour votre contribution. Elle a été postée avec succès !";
$lang['comment']['successful_edit']="Commentaire modifié avec succès.";
$lang['comment']['error_edit']="Le commentaire n'est pas assez long. Les changements ne seront pas pris en compte. Rafraîchissez la page ou tapez \"Ctrl + Z\" pour voir le contenu initial.";
$lang['comment']['moderation_msg']="Les commentaires sont modérés. Votre message apparaîtra après validation par un administrateur.";
$lang['comment']['moderation_msg_contrib']="Les contributions sont modérées. Votre contribution apparaîtra après validation par un administrateur.";
$lang['comment']['only_registered']="Seuls les utilisateurs enregistrés peuvent poster des commentaires. Si vous disposez d'un compte, <a href=\"%s\" class=\"%s\">authentifiez-vous</a>.";
$lang['comment']['only_registered_contrib']="Seuls les utilisateurs enregistrés peuvent poster des contributions. Si vous disposez d'un compte, <a href=\"%s\" class=\"%s\">authentifiez-vous</a>.";
$lang['comment']['create_account']="Vous pouvez aussi <a href=\"%s\" class=\"%s\">créer un compte</a>.";
$lang['comment']['to_moderate']="Message en attente de validation par un administrateur";
$lang['comment']['posted_in']="posté dans";
$lang['comment']['approve']="approuver";
$lang['comment']['disapprove']="désapprouver";
$lang['comment']['approved']="approuvé";
$lang['comment']['disapproved']="désapprouvé";
$lang['comment']['all_approved']="approuvés";
$lang['comment']['all_disapproved']="désapprouvés";
$lang['comment']['delete']="supprimer définitivement";
$lang['comment']['registered_user']="enregistré";

$lang['comment']['published']="Publiés";
$lang['comment']['awaiting']="En attente";

$lang['comment_map']['news']="actualité";
$lang['comment_map']['project']="projet";
$lang['comment_map']['workgroups']="groupe de travail";
$lang['comment_map']['publication']="publication";
$lang['comment_map']['report']="rapport";
$lang['comment_map']['indicator']="indicateur";
$lang['comment_map']['files']="fichier";
$lang['comment_map']['contribute']="contribution";

/*	nommage rubrique module
 *  	*/
$lang['comment']['list']= 'Consultation des commentaires';
$lang['comment']['det']= 'Détails du commentaire';
$lang['comment']['unsubscribe_title']='Désabonnement à la notification automatique des commentaires';
$lang['comment']['unsubscribe_successful']="Vous n'êtes plus abonné aux commentaires.";

/*	check integrité des données
 *  	*/
$lang['comment']['no_name']="Veuillez indiquer votre nom.";
$lang['comment']['no_email']="Veuillez indiquer votre email.";
$lang['comment']['no_body']="Veuillez entrer votre message.";


/*	divers
 *  	*/
$lang['comment']['nb_total']="%d commentaires sont stockés dans la base de données.";
$lang['comment']['status_filter']='Afficher par statut';
$lang['comment']['module_filter']='Afficher par module';
$lang['comment']['module']='Module';
$lang['comment']['all']='Afficher la liste complète';
$lang['comment']['noresult']='Aucun commentaire ne correspond à ce(s) critère(s) de sélection ';


/*	public
 *  	*/
$lang['comment']['mail_subject_newcomment']='Un nouveau commentaire a été posté - %s';
$lang['comment']['mail_subject_moderate']='Modérer un nouveau commentaire - %s';
$lang['comment']['mail_body1']='%s a posté un nouveau commentaire dans %s';
$lang['comment']['mail_body2']='modérer';
$lang['comment']['mail_body3']='Vous recevez ce message car vous vous êtes abonné. Pour ne plus recevoir de notification, suivez ce lien : ';
$lang['comment']['mail_body_auth'] = 'Important : Vous devez être authentifié pour y avoir accès.';

/*	public
 *  	*/

$lang['comment']['name2']='commentaire(s)';

$lang['comment']['contribute_item']='Contributions';
$lang['comment']['contribute_title']='Donnez votre opinion !';
$lang['comment']['contribute_chapo']='La plateforme mise en place vous offre la possibilité de vous exprimer sur notre démarche.';

$lang['comment']['contrib_none']='A ce jour, aucune contribution n\'a été reçue.';
$lang['comment']['contrib_singular']='A ce jour, une contribution a été reçue.';
$lang['comment']['contrib_plural']='A ce jour, %s contributions ont été reçues.';

$lang['comment']['help_1']='Vous pouvez supprimer définitivement un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';
$lang['comment']['help_2']='Vous pouvez approuver un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';
$lang['comment']['help_3']='Vous pouvez désapprouver un commentaire en cliquant sur l\'icône de suppression qui lui est associée.';

?>
